@@ -1,4 +1,4 @@
-from pytest_perf.deco import extras, deps
+from pytest_perf.deco import extras, deps, control
 
 
 @extras('testing')
@@ -18,3 +18,15 @@ def simple_perf_test():
 
     dir(abc)
     assert isinstance(abc, types.ModuleType)
+
+
+@control('v0.9.2')
+def diff_from_oh_nine_two_perf():
+    pass
+
+
+def check_perf_isolated():
+    import pytest_perf  # end warmup
+
+    path = str(pytest_perf.__path__)
+    assert 'pip-run' in path, path
